/// \file    ArgoneutTWQProjectionView.cxx
/// \brief   Class to aid in the rendering of ArgoNeuT reconstruction objects
/// \author  andrzej.szelc@yale.edu
#include <cmath>
#include <map>

#include "TMarker.h"
#include "TBox.h"

#include "TGButton.h"
#include "TH1.h"
#include "TLine.h"
#include "TPolyLine.h"
#include "TPolyLine3D.h"
#include "TPolyMarker3D.h"
#include "TCanvas.h"


//#include "EventDisplayBase/evdb.h"
#include "nutools/EventDisplayBase/View2D.h"
#include "nutools/EventDisplayBase/View3D.h"
#include "nutools/EventDisplayBase/EventHolder.h"
//#include "Geometry/geo.h"
#include "larcore/Geometry/Geometry.h"
#include "lareventdisplay/EventDisplay/RecoDrawingOptions.h"
#include "lareventdisplay/EventDisplay/ColorDrawingOptions.h"
#include "lareventdisplay/EventDisplay/RawDrawingOptions.h"
#include "lareventdisplay/EventDisplay/EvdLayoutOptions.h"
#include "lardataobj/RecoBase/Hit.h"
#include "lardataobj/RecoBase/Cluster.h"
#include "lardataobj/RecoBase/Event.h"
#include "lardataobj/RecoBase/Shower.h"
#include "lardataobj/RecoBase/SpacePoint.h"
#include "lardataobj/RecoBase/Track.h"
#include "lardataobj/RecoBase/Vertex.h"
#include "lardataalg/DetectorInfo/LArProperties.h"
#include "lardataalg/DetectorInfo/DetectorProperties.h"
#include "lardata/Utilities/AssociationUtil.h"
#include "canvas/Persistency/Common/FindMany.h"

#include "ArgoneutEventDisplay/ArgoneutTWQProjectionView.h"
#include "ArgoneutEventDisplay/ArgoneutDrawingOptions.h"
#include "T962_Objects/MINOS.h"


#include "art/Framework/Services/Registry/ServiceHandle.h"
#include "art/Framework/Principal/Event.h"
#include "canvas/Persistency/Common/Ptr.h"
#include "canvas/Persistency/Common/PtrVector.h"
#include "art/Framework/Principal/Handle.h" 
#include "messagefacility/MessageLogger/MessageLogger.h"
#include "lareventdisplay/EventDisplay/InfoTransfer.h"


namespace {
#if 0
   // Utility function to make uniform error messages.
   void writeErrMsg(const char* fcn,
                    cet::exception const& e)
   {
      mf::LogWarning("ArgoneutTWQProjectionView") << "ArgoneutTWQProjectionView::" << fcn
                                               << " failed with message:\n"
                                               << e;
   }
#endif // 0
}

//static const int kNCOLS = 14;
//static const int kColor[kNCOLS] = { 2, 3, 4, 5, 6, 7, 8, 29, 30, 38, 40, 41, 42, 46 };

namespace argoevd{

   //......................................................................
   ArgoneutTWQProjectionView::ArgoneutTWQProjectionView(TGMainFrame* mf) : TWQProjectionView(mf) 
   {
     
    art::ServiceHandle<evd::EvdLayoutOptions>        evdlayoutopt;  
    if(evdlayoutopt->fShowClusterSection)      
      {SetUpClusterDeleteButtons();
       evdb::Canvas::fCanvas->Update();
      }
   }

   //......................................................................
   ArgoneutTWQProjectionView::~ArgoneutTWQProjectionView() 
   {
 
   }

   //......................................................................

    //......................................................................
  void ArgoneutTWQProjectionView::SetUpSideBar()
  { 
    std::cout << "===============SetUp SideBar ArgoNeuT!!! " << std::endl;
    SetUpZoomButtons();
    SetUpPositionFind();
    SetUpClusterButtons();
   
  }
 
 
   void ArgoneutTWQProjectionView::SetUpClusterDeleteButtons()
   {
     
    fDeleteLast=new TGTextButton(fVFrame, "&Delete Last", 150);
    fDeleteLast->Connect("Clicked()", "evd::TWQProjectionView",this,"SetTestFlag(=111)");
	
    fDeleteEvent=new TGTextButton(fVFrame, "&Delete Event",0);
    fDeleteEvent->Connect("Clicked()","evd::TWQProjectionView", this, "SetTestFlag(=222)");
	   
     
    fVFrame->AddFrame(fDeleteLast,new TGLayoutHints(kLHintsTop|kLHintsLeft,0,0,5,1));
    fVFrame->AddFrame(fDeleteEvent,new TGLayoutHints(kLHintsTop | kLHintsLeft,0,0,5,1));
     
   }
 
 
 
    
    
}// namespace
////////////////////////////////////////////////////////////////////////
